from Data import DataSets
from Util import Sci, Set

import BiomassComp # from the Model/tools directory, module defining biomass fluxes for this model



def O2Scan(m, lo=0, hi=0.008, nPoints=100):

    lp = m.GetLP() # Generate a linear program representing this model
    lp.SetObjective(m.sm.cnames) # Targets are all reaction (minimise by default)

    fd = BiomassComp.FluxDic(m) # dictionary relating biomass transport steps to their respective fluxes
    lp.SetFixedFlux(fd) # set the output fluxes to account for biomass components

    ds = DataSets.DataSet(ItemNames=["O2Lim","ObjVal"])
    # DataSet to hold the results "O2Lim" and ObjVal will be the first two columns
    ds.SetPlotX("O2Lim")  # We will use this as the x axis for plotting

    for O2Lim in Sci.linspace(lo, hi, nPoints): # nPoints evenly spaced values of O2Lim, between lo and hi
        lp.SetFluxBounds({"O2_tx":(0, O2Lim)}) # constrain the upper bound of the O2 transport flux to the value of O2Lim
        lp.Solve(False) # solve the problem - False turns off reporting
        print ".", # gives an indication of progress made
        ds.UpdateFromDic(lp.GetPrimSol()) # update the results with the solution
        ds[-1,"O2Lim"] = O2Lim # record the value of O2Lim (it's not part of the solution)
        ds[-1, "ObjVal"] = lp.GetObjVal() # ditto for the objective value

    return ds

def GetNonBiomass_tx(m):
    return Set.Complement(filter(lambda s: "_tx" in s, m.sm.cnames),BiomassComp.FluxDic(m) )
    
        
                    

    
