from Bioinf import Biomass

#### for now use locally modified MolWts ###
import ExtraMolWts
Biomass.MolWts.MolWts.update(ExtraMolWts.ExtraMolWts)


#Geobacillus biomass composition, based on Tang_09

Prot = Biomass.Composition(
    0.545,{ #prot content in Tang is 64%, which results in a sum >1, adjusted down.
    "GLY" : 0.0766,
    "HIS" : 0.0192,
    "SER" : 0.0383,
    "GLT" : 0.067,
    "ARG" : 0.0383,
    "PHE" : 0.0383,
    "TRP" : 0.0201,
    "L-ASPARTATE" : 0.0479,
    "VAL" : 0.0766,
    "ILE" : 0.0575,
    "ASN" : 0.0479,
    "GLN" : 0.067,
    "MET" : 0.0192,
    "PRO" : 0.0383,
    "LEU" : 0.0766,
    "LYS" : 0.067,
    "TYR" : 0.0192,
    "CYS" : 0.0125,
    "L-ALPHA-ALANINE" : 0.1149,
    "THR" : 0.0575,
        }
    )


DNA = Biomass.Composition(
    0.0268, { 
    "DCTP" : 0.0625,
    "DATP" : 0.0795,
    "DGTP" : 0.0625,
    "TTP" : 0.0795,
        }
    )

RNA = Biomass.Composition(
    0.0676, { 
    "CTP" : 0.1346,
    "ATP" : 0.1905,
    "GTP" : 0.2456,
    "UTP" : 0.1461,
        }
    )



CellWall =  Biomass.Composition( #no geobacillus specific data on cell wall, use B. subtilus
    0.2313,
    {
       "Peptidoglycan" : 0.45,
       "Teichoic_Acid": 0.55
    }
)


Cofactors = Biomass.Composition( #ratios based on B. subtilis values, from Oh_07
    0.051,
    {
    "NADPH" : 0.0121,
    "ACETYL-COA" : 0.000973,
    "FAD" : 0.001892,
    "NAD" : 0.8365,
    "CPD-12575" : 0.0583813,
    "NADP" : 0.05405,
    "SUC-COA" : 0.000058,
    "5-METHYL-THF" : 0.0189,
    }
)

Lipid = Biomass.Composition(    # data based on Rosa_00 for G. staerothermophilus
                                # neutral lipid as 1,2-diacylglycerol.
                                # diphosphatidylglycerol from as cardiolipin
                                # phosphoglycolipid not present in metacyc, ignored along with coumpounds X_n in
                                # paper, other polar componets adjusted to add up to 1.0.
                                # All phosholipids are repressented with 16,15iso,16iso and 17iso FA,
                                # proportions according to Tang_09
    0.0784, {
        "DGR": 0.0511,
        "PE": 0.271,
        "PG": 0.0679,
        "CLPN": 0.1203,
        
        "DGR_15iso": 0.0096,
        "PE_15iso": 0.051,
        "PG_15iso": 0.0128,
        "CLPN_15iso": 0.02261,

        "DGR_16iso": 0.0279,
        "PE_16iso": 0.142,
        "PG_16iso": 0.0370,
        "CLPN_16iso": 0.0657,

        "DGR_17iso": 0.0114,
        "PE_17iso": 0.0606,
        "PG_17iso": 0.0152,
        "CLPN_17iso": 0.0269
    }
)
        





All = Biomass.Composition(
    1.0, 
    {
        "CellWall": CellWall,
        "Prot" : Prot,
        "DNA" : DNA,
        "RNA": RNA,
        "Cofactors":Cofactors,
        "Lipid":Lipid,
    }
)

def FluxDic(m, mu=0.3, ATPMaint=6.1e-3, ATPGrowth=41e-3, ATPase="ATPase"):
    ''' pre : m - the model
              mu - growth rate
              ATPMaint - ATP maintenance demand - mol.gDW^{-1}.hr^{-1}
              ATPGrowth - ATP Growth requirement = mol.gDW^{-1}
        post: dictionary of flux rates according to biomass composition, growth rate and ATP demand.
    '''
    
    rv = {}

    for met in All.GetLeaves():
        xp = Biomass.WhatExports(m,met)
        
        if xp == None:
            print "no tx for ", met
        else:
            rv[xp] = -All.MolsOf(met)*mu

    rv[ATPase] = mu * ATPGrowth + ATPMaint 
        
    return rv


def FermDic():
    return {
        'EtOH_tx' : (None,0.0),
        'Ac_tx' : (None,0.0),
        'Formate_tx' : (None,0.0),
        'Suc_tx' : (None,0.0),
        'Lact_tx' : (None,0.0),
        'Pyr_tx' : (None,0.0),
    }
